.. _plot_wavelengths:

laue_dials.plot_wavelengths
===========================

Introduction
------------

.. python_string:: laue_dials.command_line.plot_wavelengths.help_message

Basic parameters
----------------

.. phil:: laue_dials.command_line.plot_wavelengths.working_phil
   :expert-level: 0
   :attributes-level: 0


Full parameter definitions
--------------------------

.. phil:: laue_dials.command_line.plot_wavelengths.working_phil
   :expert-level: 2
   :attributes-level: 2
